#!/usr/bin/perl -w


#====================================================================
# What's this ?
#====================================================================
# Script designed for cacti [ http://www.cacti.net ]
#
# Tested with perl v5.8.5 built for i386-linux-thread-multi 
# Cacti Version	0.8.6j
# Get intake_temp intake_hum blowing_temp using snmp vars
# pCOweb integrated in lexnox Unit
# General information: 	pcoweb@carel.com
# Used Mib decription : CAREL-ahu_pco_v18.MIB
# 
# 
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#====================================================================


# --------------------------------------------------
# ARGV[0] = <hostname> required
# ARGV[1] = <snmp version> required
# ARGV[2] = <snmp community> required
# ARGV[3] = <snmp port> required
# ARGV[4] = <snmp timeout> required
# --------------------------------------------------

$in_hostname 	= $ARGV[0] if defined $ARGV[0];
$in_version 	= $ARGV[1] if defined $ARGV[1];
$in_community 	= $ARGV[2] if defined $ARGV[2];
$in_port 	= $ARGV[3] if defined $ARGV[3];
$in_timeout 	= $ARGV[4] if defined $ARGV[4];


# usage notes
if (
	( ! defined $in_hostname ) ||
	( ! defined $in_version ) ||
	( ! defined $in_community ) ||
	( ! defined $in_port ) ||
	( ! defined $in_timeout )
	) {
	print 	" Get intake_temp intake_hum blowing_temp using snmp vars on pCOweb integrated in lexnox Unit\n
                usage:\n
		$0 <host> <snmp version> < snmp community> <snmp port> <snmp timeout>\n
                Output intake_temp intake_hum blowing_temp\n\n";
	exit;
}

#Here you can customize your snmp OIDs
my $_cmd_intake_temp= "snmpget -OvqU -v $in_version  -c $in_community -t $in_timeout $in_hostname:$in_port 1.3.6.1.4.1.9839.2.1.2.4.0";
my $_cmd_intake_hum= "snmpget -OvqU -v $in_version  -c $in_community -t $in_timeout $in_hostname:$in_port 1.3.6.1.4.1.9839.2.1.2.1.0";
my $_cmd_blowing_temp= "snmpget -OvqU -v $in_version  -c $in_community -t $in_timeout $in_hostname:$in_port 1.3.6.1.4.1.9839.2.1.2.5.0";


my $_intake_temp = `$_cmd_intake_temp`;
my $_intake_hum = `$_cmd_intake_hum`;
my $_blowing_temp = `$_cmd_blowing_temp`;

#On lexnox pcoweb, temp, hum are x10 C;
$_intake_temp = $_intake_temp/10;
$_intake_hum = $_intake_hum/10;
$_blowing_temp = $_blowing_temp/10;


chomp($_intake_temp);
chomp($_intake_hum);
chomp($_blowing_temp);


# if you want to translate here, be sure to modify "GET Clim_lenox " cacti date input methode (simple ;)
print "temperature:$_intake_temp humidite:$_intake_hum soufflage:$_blowing_temp\n";
